is_available

Function is_available 

pub fn is_available() -> bool
Returns true if Apple Intelligence is available and ready on this device.

This is a cheap synchronous check. See availability for the specific reason when this returns false.