pub fn is_available() -> boolExpand description
Returns true if Apple Intelligence is available and ready on this device.
This is a cheap synchronous check. See availability for the specific reason
when this returns false.
pub fn is_available() -> boolReturns true if Apple Intelligence is available and ready on this device.
This is a cheap synchronous check. See availability for the specific reason
when this returns false.